# Summary

In portfolio management contexts, rebalancing is often believed to add value. But what is rebalancing? Rebalancing is best understood by contrasting buy-and-hold portfolios and constant proportion portfolios. Buy-and-hold portfolios naturally concentrate over time into the best performing assets. They don't trade. Constant proportion portfolios trade to counter the concentration tendency. They sell the winners and buy the losers. 

Under what condition does rebalancing pay off? Rebalancing will pay off as seen from a terminal date if, on average, the price at which a quantity has been bought (respectively sold) is lower (resp. higher) than either the price at which it is subsequently sold (resp. bought) if that happens or the terminal price. This condition is meant to hold across all trades triggered by rebalancing.

What is the likelihood that this condition holds? It depends. First, all that matters for the relative performance of a constant proportion portfolio versus its buy-and-hold counterpart is relative prices. Clearly, if relative prices keep oscillating around an average value, rebalancing will in the end pay off. Oscillations create occasions to buy low and sell high. Rebalancing has great potential in such contexts. But relative prices can typically diverge. In a stock context, Apple has beaten many other competitors over a long period of time. 

In a multi-asset context the most important quantity is the relative price of the equity index versus the price of the bond index. The graph below shows that this quantity has been relatively stable over the last thirty years, indicating that this period was favourable to rebalancing. One should however caution that this relative price should in principle trend. After all, bonds and equities don't have the same volatility. Even if they had similar Sharpe ratios, their risk premia should be different. It could be that the historical stationarity of the relative price should not be expected to persist.


# Understanding rebalancing

Rebalancing is best understood starting with buy-and-hold. Buy-and-hold consists in keeping the number of contracts held in a portfolio constant. If \(n=(n_{i})_{i=1,\ldots,N}\) denotes the constant number of shares (say) held in the portfolio, the change in value of the portfolio will reflect the change in value of the contracts over the given interval \([t,t+1]\), i.e. \(p_{i,t+1}-p_{i,t}\), times the quantities held. This change in value is thus:
\[V_{bh,t+1}-V_{bh,t}=\sum_{i=1}^{N}n_{i}(p_{i,t+1}-p_{i,t}).\]

To understand rebalancing, it is useful to introduce the proportion of the value invested on a given contract:
\[\pi_{i,t}=\frac{n_{i}p_{i,t}}{\sum_{i=1}^{N}n_{i}p_{i,t}}\]
As a reminder, using proportions, the change of value of a portfolio is accounted by:
\[\frac{V_{\pi,t+1}}{V_{\pi,t}}=\sum_{i=1}^{N}\pi_{i}\frac{p_{i,t+1}}{p_{i,t}}.\]

In a buy-and-hold portfolio, the proportions invested on the most performing assets rise while the proportions invested on the least performing assets fall, as can be easily checked. Rebalancing can be conceived as leaning against this natural tendency, i.e. as trading in such a way that the asset proportions are less distorted by relative performance than implied by the buy-and-hold policy. This principle is best illustrated by constant proportion portfolios. These are portfolios that trade so as to keep the proportions \(\pi_{i,t}\) constant. The trading operation carried out to prevent the change in proportions is the rebalancing operation. This amounts to selling the winners and buying the losers.

When does rebalancing work? The value of a constant proportion portfolio evolves according to:
\[V_{\pi,t+1}-V_{\pi,t}=\sum_{i=1}^{N}n_{i,\pi,t}(p_{i,t+1}-p_{i,t}),\]
where we have accounted for the fact that the quantities held \(n_{i,\pi,t}\) change with time. Assume the proportions and quantities have been chosen such that the buy-and-hold portfolio and the constant proportion portfolios are identical at date \(0\). We can subsequently track the difference in quantities induced by rebalancing. Let's call
\[\Delta n_{i,t}=n_{i,\pi,t}-n_{i},\]
the difference in quantities held in the constant proportion portfolio and in the buy-and-hold portfolio. Note that we made sure that \(\Delta n_{i,0}=0.\). Then assuming both portfolios are initialized with the same amount of money, the different in the value of the two portfolios at terminal date \(T\) is just:
\[V_{\pi,T}-V_{bh,T}=\sum_{t=0}^{T-1}\sum_{i=1}^{N}\Delta n_{i,t}(p_{i,t+1}-p_{i,t}).\]

If we designed a convention to keep track of individual trades (for example using last-in first-out accounting), we could split this pay-off into trades, initiated then either terminated or carried up to date \(T\). The cumulated performance \(V_{\pi,T}-V_{bh,T}\) would then depend on the sum of the P&Ls of these individuals trades.

In practice, the outcome depends on relative prices. Indeed, one can quote prices against any convenient numeraire. Whether \(V_{\pi,T}-V_{bh,T}\) is positive or negative does not depend on the chosen numeraire. We can thus choose the first asset as the numeraire. This amounts to assuming \(p_{1,t}=1\) at all dates. Other prices are then prices quoted relatively to that of the first asset. Then, quite intuitively, the best situation is one where all relative prices oscillate without ever diverging. One can show (this is beyond this simple note) that rebalancing almost surely beats buy-and-hold if one is sufficiently patient. In contrast, if relative prices have different trends, buy-and-hold should outperform. In practice, both behaviors will be observed in a sample and the outcome will depend on the mix between cycles and trends.

I illustrate this in a multi-asset context where the most important relative price is that of stocks versus bonds. The graph below shows that this quantity has been quite stable over the last thirty years, indicating that this period was favourable to rebalancing. One should however caution that this relative price should actually trend. After all, bonds and equities don't have the same volatility. Even if they have similar Sharpe ratios, their risk premia should be different. The historical stationarity of the relative price should not be expected to persist.


